# Hygieia
Hygieia — The Python Package that Utilizes Feature Selection to Predict the Clinical and Genomic Basis of Disease

Hygieia is an open-source Python package that conducts feature selection on patient records, extracting
impactful information about non-genomic and genomic characteristics. Hygieia combines cutting-edge
and tried-and-tested gene expression analysis methods, placing machine learning algorithms and
classical statistics tests at its user’s fingertips. Hygieia is simple to use and provides easy-to-interpret
results, cementing itself as a fantastic tool for scientists without a solid computational background. The
Ahmed Lab plans to expand Hygieia further as we explore the uncharted intersection between artificial
intelligence and gene expression analysis, incorporating a vaster array of feature selection methods into
the package in the future.
